===============
SMS for Pyramid
===============

.. image:: https://img.shields.io/pypi/v/pyramid_sms.svg
        :target: https://pypi.python.org/pypi/pyramid_sms

.. image:: https://img.shields.io/travis/miohtama/pyramid_sms.svg
        :target: https://travis-ci.org/miohtama/pyramid_sms

.. image:: https://readthedocs.org/projects/pyramid_sms/badge/?version=latest
        :target: https://readthedocs.org/projects/pyramid_sms/?badge=latest
        :alt: Documentation Status


SMS text messaging services for `Pyramid <http://trypyramid.com>`_ web framework.

* Free software: ISC license

* Documentation: https://pyramid_sms.readthedocs.org.

Features
--------

* Configurable SMS backend

* Send outbound SMS using `Twilio <https://twilio.com>`_ or dummy backend for unit testing

* Asynchronous operations that do not block HTTP response with `Websauna <https://websauna.org>`_

* API type hinting

Author
------

`Mikko Ohtamaa <https://opensourcehacker.com>`_.

Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
